* sgn
    * [apps](sgn/apps.md)
    * [base](sgn/base.md)
    * [bottle](sgn/bottle.md)
    * [compose](sgn/compose.md)
    * [control](sgn/control.md)
    * [frames](sgn/frames.md)
    * [groups](sgn/groups.md)
    * [logger](sgn/logger.md)
    * [profile](sgn/profile.md)
    * [sinks](sgn/sinks.md)
    * [sources](sgn/sources.md)
    * [subprocess](sgn/subprocess.md)
    * [transforms](sgn/transforms.md)
    * [validator](sgn/validator.md)
    * [visualize](sgn/visualize.md)
